@@ -10,8 +10,8 @@ from events.forms import EventForm
 class EventAdmin(admin.ModelAdmin):
     form = EventForm
     list_filter = 'frecuency',
-    list_display = 'beginning', 'time', 'duration', 'frecuency', 'repetitions', 'end'
-    fields = 'beginning', 'time', 'duration', 'frecuency', 'repetitions', 'end'
+    list_display = 'beginning', 'time', 'duration', 'interval', 'frecuency', 'repetitions', 'end'
+    fields = 'beginning', 'time', 'duration', 'interval', 'frecuency', 'repetitions', 'end'
     actions = 'finish',
     date_hierarchy = 'beginning'
 
